Models
======
.. automodapi:: pykeen.models
    :no-heading:
    :headings: --

Base Classes
------------
.. currentmodule:: pykeen.models.base
.. autosummary::
    :toctree: generated/

    Model
    EntityEmbeddingModel
    EntityRelationEmbeddingModel
    MultimodalModel
